@@ -15,7 +15,9 @@ public enum ChangeTableRequestType {
 	DELETECOLUMN,
 	SPLITCOLUMN,
 	GROUPBY,
+	TIMEAGGREGATION,
 	MERGECOLUMN,
+	CHANGEPOSITIONCOLUMNS,
 	CHANGECOLUMNLABEL,
 	COLUMNFILTER,
 	CHANGETABLETYPE,
@@ -26,10 +28,14 @@ public enum ChangeTableRequestType {
 	DENORMALIZE,
 	TEMPLATEAPPLY,
 	COLUMNREPLACE,
+	COLUMNREPLACEBYEXPRESSION,
 	COLUMNREPLACEBATCH,
 	ROLLBACK,
 	EDITROW,
 	SHARE,
+	GEOSPATIALCREATECOORDINATES,
+	DOWNSCALECSQUARE,
 	TASKRESUME,
-	TASKRESUBMIT;
+	TASKRESUBMIT,
+	STATISTICALOPERATION;
 }
